Files
:::::::::::::::::::::::::::::::::::::::::::

.. index::
    single: File

.. toctree::
    :caption: Files
    :maxdepth: 3

    persistence.rst
    openingFiles.rst
    textFiles.rst
    readingFiles.rst
    searching.rst
    userNames.rst
    tryExceptOpen.rst
    writingFiles.rst
    debugging.rst
    glossary.rst
    Exercises.rst
    mixedupCode.rst
    writeCode.rst
    file-group.rst
    csv-file-group.rst
    csv-reader-file-group.rst
